diff src/fileio.c @ 15313:0fad77a676b7

(Fexpand_file_name) [WINDOWSNT]: Don't strip trailing / when newdir is just "//". (Ffile_name_directory) [WINDOWSNT]: Return Qnil if filename is a partial UNC name such as "//foo".
author Richard M. Stallman <rms@gnu.org>
date Sat, 01 Jun 1996 02:23:06 +0000
parents b2c682fcd3ef
children 6fd4e01fd332
line wrap: on
line diff
--- a/src/fileio.c	Fri May 31 20:12:44 1996 +0000
+++ b/src/fileio.c	Sat Jun 01 02:23:06 1996 +0000
@@ -348,6 +348,12 @@
 
   if (p == beg)
     return Qnil;
+#ifdef WINDOWSNT
+  /* We can consider the partial UNC name //machine to be a
+     directory name, but not just // on its own. */
+  if (p == beg + 1 && IS_DIRECTORY_SEP (p[-1]))
+    return Qnil;
+#endif
 #ifdef DOS_NT
   /* Expansion of "c:" to drive and default directory.  */
   if (p == beg + 2 && beg[1] == ':')
@@ -1252,9 +1258,14 @@
 
   if (newdir)
     {
-      /* Get rid of any slash at the end of newdir.  */
+      /* Get rid of any slash at the end of newdir, unless newdir is
+       just // (an incomplete UNC name). */
       length = strlen (newdir);
-      if (IS_DIRECTORY_SEP (newdir[length - 1]))
+      if (IS_DIRECTORY_SEP (newdir[length - 1])
+#ifdef WINDOWSNT
+	  && !(length == 2 && IS_DIRECTORY_SEP (newdir[0]))
+#endif
+	  )
 	{
 	  unsigned char *temp = (unsigned char *) alloca (length);
 	  bcopy (newdir, temp, length - 1);